pub struct Button { /* private fields */ }Expand description
Yew implementation of the Bulma button element.
Yew implementation of the button element, based on the specification found in the Bulma button element documentation.
Examples
use yew::prelude::*;
use yew_and_bulma::elements::button::Button;
#[function_component(App)]
fn app() -> Html {
html! {
<Button>{"A button"}</Button>
}
}Trait Implementations
Sourceimpl BaseComponent for Buttonwhere
Self: 'static,
impl BaseComponent for Buttonwhere
Self: 'static,
Sourcetype Properties = ButtonProperties
type Properties = ButtonProperties
The Component’s Properties.
Sourcefn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
fn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
Updates component’s internal state.
Sourcefn changed(
&mut self,
_ctx: &Context<Self>,
_old_props: &Self::Properties,
) -> bool
fn changed( &mut self, _ctx: &Context<Self>, _old_props: &Self::Properties, ) -> bool
React to changes of component properties.
Sourcefn view(&self, ctx: &Context<Self>) -> HtmlResult
fn view(&self, ctx: &Context<Self>) -> HtmlResult
Returns a component layout to be rendered.
Sourcefn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
fn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
Notified after a layout is rendered.
Sourcefn prepare_state(&self) -> Option<String>
fn prepare_state(&self) -> Option<String>
Prepares the server-side state.
Sourceimpl FunctionProvider for Button
impl FunctionProvider for Button
Sourcetype Properties = ButtonProperties
type Properties = ButtonProperties
Properties for the Function Component.
Sourcefn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult
fn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult